Enum ChatTask
pub enum ChatTask {
Send,
Execute(Vec<ToolCall>, Option<BotId>),
Stop,
Load,
}Expand description
Represents complex (mostly async) operations that may cause multiple mutations over time.
Variants
Send
Causes the whole list of messages to be sent to the currently selected bot (from state.bot_id) and starts the streaming response work in the background.
Execute(Vec<ToolCall>, Option<BotId>)
Calls the given MCP tools. If a bot is specified, successful tool calls will be processed by that bot.
Stop
Interrupts the streaming started by Send.
Load
Should be triggered to start fetching async data (e.g. bots).
Eventually, the state will contain the list of bots or errors as messages.