Enum ClientErrorKind
pub enum ClientErrorKind {
Network,
Response,
Format,
Unknown,
}Expand description
The standard error kinds a client implementatiin should facilitate.
Variants
Network
The network connection could not be established properly or was lost.
Response
The connection could be established, but the remote server/peer gave us an error.
Example: On a centralized HTTP server, this would happen when it returns an HTTP error code.
Format
The remote server/peer returned a successful response, but we can’t parse its content.
Example: When working with JSON APIs, this can happen when the schema of the JSON response is not what we expected or is not JSON at all.
Unknown
A kind of error that is not contemplated by this library at the client layer.
Implementations
impl ClientErrorKind
impl ClientErrorKind
pub fn to_human_readable(&self) -> &str