Enum EntityId
pub enum EntityId {
User,
System,
Bot(BotId),
Tool,
App,
}Expand description
Indentify the entities that are recognized by this crate, mainly in a chat.
Variants
User
Represents the user operating this app.
System
Represents the system/developer expected by many LLMs in the chat
context to customize the chat experience and behavior.
Bot(BotId)
Represents a bot, which is an automated assistant of any kind (model, agent, etc).
Tool
Represents tool execution results and tool-related system messages. Maps to the “tool” role in LLM APIs.
App
This app itself. Normally appears when app specific information must be displayed (like inline errors).
It’s not supposed to be sent as part of a conversation to bots.