VecEffect

Enum VecEffect 

pub enum VecEffect<'a, T> {
    Insert(usize, &'a [T]),
    Update(usize, &'a T, &'a T),
    Remove(usize, usize, &'a [T]),
}
A primitive operation that will be performed on a Vec<T> as a result of a higher level and more optimized VecMutation.

Variants



Insert(usize, &'a [T])

The given NEW items will be inserted at the given index.

Means the length of the list will INCREASE by the length of items.



Update(usize, &'a T, &'a T)

The EXISTING item at the given index will be replaced with a new value.

First sample is the previous value, second sample is the new value.

Means the length of the list will STAY THE SAME.



Remove(usize, usize, &'a [T])

The specified range of EXISTING items will be removed.

The sample at the end is the slice of items that will be removed.

Means the length of the list will DECREASE by end - start.