Struct Bot
pub struct Bot {
pub id: BotId,
pub name: String,
pub avatar: EntityAvatar,
pub capabilities: BotCapabilities,
}Expand description
Represents a bot, which is an automated assistant of any kind (model, agent, etc).
WARNING
This is an “ideal” representation. However, OpenAI-compatible APIs will only
give us the model id (though the /models endpoint) and nothing else. Therefore,
for most client implementations hitting such APIs, the name and the avatar may be
set from the id, and capabilities will be a best-effort guess or a fixed set based
on the client itself.
For example, the crate::clients::openai::OpenAiClient will simply list all
models available at /models, with a [BotCapability::TextOutput] as this client
is intended for text-based conversations. However, realtime and image models will also
be there with that capability incorrectly set.
Depending on your use case, it recommended to either:
- Ignore the capabilities field for
Bots coming from such clients. - Override them if you are working with concrete models you know the capabilities of.
- Try to filter models that should not be listed by the client in the first place (e.g., image and realtime models in a text-only client).
Fields
id: BotIdname: Stringavatar: EntityAvatarcapabilities: BotCapabilitiesTrait Implementations