Struct BotId
pub struct BotId(/* private fields */);Expand description
Identifies any kind of bot, local or remote, model or agent, whatever.
Normally, this is just the model name or id as known by the provider.
Implementations