Struct ChatState
pub struct ChatState {
pub messages: Vec<Message>,
pub is_streaming: bool,
pub bots: Vec<Bot>,
pub load_status: Status,
pub bot_id: Option<BotId>,
}Expand description
State of the chat that you should reflect in your view component/widget/element.
Fields
messages: Vec<Message>The chat history sent as context to LLMs.
is_streaming: boolIndicates that the LLM is still streaming the response (“writing”).
bots: Vec<Bot>The bots that were loaded from the configured client.
load_status: Statusbot_id: Option<BotId>The currently selected bot for this chat.
Implementations