Struct ClientError
pub struct ClientError { /* private fields */ }Expand description
Standard error returned from client operations.
Implementations
impl ClientError
impl ClientError
pub fn new(kind: ClientErrorKind, message: String) -> ClientError
pub fn new(kind: ClientErrorKind, message: String) -> ClientError
Construct a simple client error without source.
If you have an underlying error you want to include as the source, use ClientError::new_with_source instead.
pub fn new_with_source<S>(
kind: ClientErrorKind,
message: String,
source: Option<S>,
) -> ClientError
pub fn new_with_source<S>( kind: ClientErrorKind, message: String, source: Option<S>, ) -> ClientError
Construct a client error using an underlying error as the source.
pub fn with_details(self, details: String) -> ClientError
pub fn with_details(self, details: String) -> ClientError
Attach raw technical details (e.g. HTTP response body) to this error.
pub fn kind(&self) -> ClientErrorKind
pub fn kind(&self) -> ClientErrorKind
Error kind accessor.
pub fn take_details(&mut self) -> Option<String>
pub fn take_details(&mut self) -> Option<String>
Take the raw technical details out, leaving None in place.