MapClient

Struct MapClient 

pub struct MapClient<C>
where C: BotClient,
{ /* private fields */ }
Utility wrapper client that transforms the output of the underlying client.

This is just limited to synchronous transformations over successful results.

In general, it’s recommended to implement the BotClient trait directly for maximum control instead of using this.

Implementations



impl<C> MapClient<C>
where C: BotClient,

pub fn new(client: C) -> MapClient<C>

pub fn set_map_bots( &mut self, map: impl FnMut(Vec<Bot>) -> Vec<Bot> + Send + 'static, )

Sets a transformation function for the list of bots returned by the bots method.

pub fn set_map_send( &mut self, map: impl FnMut(MessageContent) -> MessageContent + Send + 'static, )

Sets a sync transformation function for the successful result of the send method.