Struct MessageContent
pub struct MessageContent {
pub text: String,
pub citations: Vec<String>,
pub reasoning: String,
pub attachments: Vec<Attachment>,
pub tool_calls: Vec<ToolCall>,
pub tool_results: Vec<ToolResult>,
pub data: Option<String>,
pub upgrade: Option<Upgrade>,
}Expand description
Standard message content format.
Fields
text: StringThe main body/document of this message.
This would normally be written in somekind of document format like markdown, html, plain text, etc. Only markdown is expected by default.
citations: Vec<String>List of citations/sources (urls) associated with this message.
reasoning: StringThe reasoning/thinking content of this message.
attachments: Vec<Attachment>File attachments in this content.
tool_calls: Vec<ToolCall>Tool calls made by the AI (for assistant messages)
tool_results: Vec<ToolResult>Tool call results (for tool messages)
data: Option<String>Non-standard data contained by this message.
May be used by clients for tracking purposes or to represent unsupported content.
This is not expected to be used by most clients.
upgrade: Option<Upgrade>Optional upgrade to realtime communication
Implementations
impl MessageContent
impl MessageContent