OpenAiImageClient

Struct OpenAiImageClient 

pub struct OpenAiImageClient(/* private fields */);
Specific OpenAI client to hit image generation endpoints.

If used as part of a [crate::clients::MultiClient], it’s recommended to add this before the standard OpenAI client to ensure it get’s priority. This is not strictly necessary if the OpenAI client recognizes and filters the image models you use.

Implementations



impl OpenAiImageClient

pub fn new(url: String) -> OpenAiImageClient

pub fn set_header(&mut self, key: &str, value: &str) -> Result<(), &'static str>

pub fn set_key(&mut self, key: &str) -> Result<(), &'static str>

pub fn get_url(&self) -> String