RouterClient

Struct RouterClient 

pub struct RouterClient { /* private fields */ }
A client that can be composed from multiple subclients to interact with all of them as one.

Bot IDs

BotIds are prefixed with the key used to insert the subclient. Take that into account when calling send or when reading the list of bots from bots.

If you are just forwarding an id that came from bots, to the send method, you don’t need to worry.

If you are creating BotIds manually you can use RouterClient::prefix and RouterClient::unprefix methods to help you.

Cache

This router works by caching the results from calling bots on each sub-client. The method will only be called for a specific sub-client if there is no cached result yet, or if the cached result contains errors.

If a client is associated with a cached result, without errors, then its bots method will not be called again.

If you need to refresh the list of bots, you will need to invalidate the cache explicitly.

Implementations



impl RouterClient

pub fn new() -> RouterClient

pub fn invalidate_all_bots_cache(&self)

Invalidates the bots cache for all sub-clients.

pub fn invalidate_bots_cache(&self, key: impl AsRef<str>)

Invalidates the bots cache for the client with the given key.

pub fn insert_client(&self, key: impl AsRef<str>, client: Box<dyn BotClient>)

Inserts a client with the given key.

pub fn remove_client(&self, key: impl AsRef<str>)

Removes a client by the key used to insert it.

pub fn get_client_cloned( &self, key: impl AsRef<str>, ) -> Option<Box<dyn BotClient>>

Gets a client by the key used to insert it, cloning it.

pub fn read_client<F, R>(&self, key: impl AsRef<str>, f: F) -> Option<R>
where F: FnOnce(&Box<dyn BotClient>) -> R,

Access a client immutably by the key used to insert it.

The closure will not be called if there is no client for the given key, but this function will give None in that case.

pub fn write_client<F, R>(&self, key: impl AsRef<str>, f: F) -> Option<R>
where F: FnOnce(&mut Box<dyn BotClient>) -> R,

Access a client mutably by the key used to insert it.

The closure will not be called if there is no client for the given key, but this function will give None in that case.

pub fn prefix(key: &str, bot_id: &BotId) -> BotId

Prefixes a bot id with the given key.

pub fn unprefix(bot_id: &BotId) -> Option<(&str, BotId)>

Unprefixes a bot id, returning the key and the original bot id.