HitExt

Trait HitExt 

pub trait HitExt {
    // Required methods
    fn primary_pointer_action_pos(&self) -> Option<DVec2>;
    fn secondary_pointer_action_pos(&self) -> Option<DVec2>;
    fn is_primary_pointer_action(&self) -> bool;
    fn is_secondary_pointer_action(&self) -> bool;
}

Required Methods

fn primary_pointer_action_pos(&self) -> Option<DVec2>

If the primary pointer action happened, returns the position where it happened.

fn secondary_pointer_action_pos(&self) -> Option<DVec2>

If the secondary pointer action happened, returns the position where it happened.

fn is_primary_pointer_action(&self) -> bool

This was a left mouse click or a simple touch screen tap.

fn is_secondary_pointer_action(&self) -> bool

This was a right mouse click or a long press on touch screen.

Implementations on Foreign Types

Source

impl HitExt for Hit

Implementors