pub enum MessagesAction {
Copy(usize),
Delete(usize),
EditSave(usize),
EditRegenerate(usize),
ToolApprove(usize),
ToolDeny(usize),
None,
}Expand description
Relevant actions that should be handled by a parent.
If includes an index, it refers to the index of the message in the list.
Variants
Copy(usize)
The message at the given index should be copied.
Delete(usize)
The message at the given index should be deleted.
EditSave(usize)
The message at the given index should be edited and saved.
EditRegenerate(usize)
The message at the given index should be edited, saved and the messages history should be regenerated from here.
ToolApprove(usize)
The tool request at the given index should be approved and executed.
ToolDeny(usize)
The tool request at the given index should be denied.
None