pub struct PromptInput {
pub deref: View,
pub empty_text: String,
pub realtime_empty_text: String,
pub task: Task,
pub interactivity: Interactivity,
pub bot_capabilities: Option<BotCapabilities>,
}Expand description
A prepared text input for conversation with bots.
This is mostly a dummy widget. Prefer using and adapting crate::widgets::chat::Chat instead.
Fields
deref: Viewempty_text: StringPlaceholder text shown when the input is empty.
realtime_empty_text: StringPlaceholder text shown when a realtime model is selected.
task: TaskIf this widget should provoke sending a message or stopping the current response.
interactivity: InteractivityIf this widget should be interactive or not.
bot_capabilities: Option<BotCapabilities>Capabilities of the currently selected bot
Implementations
Sourceimpl PromptInput
impl PromptInput
Sourcepub fn reset(&mut self, cx: &mut Cx)
pub fn reset(&mut self, cx: &mut Cx)
Reset this prompt input erasing text, removing attachments, etc.
Sourcepub fn text_input_ref(&self, cx: &Cx) -> TextInputRef
pub fn text_input_ref(&self, cx: &Cx) -> TextInputRef
Returns a reference to the inner TextInput widget.
Sourcepub fn submitted(&self, cx: &Cx, actions: &Actions) -> bool
pub fn submitted(&self, cx: &Cx, actions: &Actions) -> bool
Check if the submit button or the return key was pressed.
Note: To know what the button submission means, check Self::task or the utility methods.
pub fn call_pressed(&self, cx: &Cx, actions: &Actions) -> bool
pub fn stt_pressed(&self, cx: &Cx, actions: &Actions) -> bool
Sourcepub fn has_send_task(&self) -> bool
pub fn has_send_task(&self) -> bool
Shorthand to check if Self::task is set to Task::Send.
Sourcepub fn has_stop_task(&self) -> bool
pub fn has_stop_task(&self) -> bool
Shorthand to check if Self::task is set to Task::Stop.
Sourcepub fn set_send(&mut self)
pub fn set_send(&mut self)
Shorthand to set Self::task to Task::Send.
Sourcepub fn set_stop(&mut self)
pub fn set_stop(&mut self)
Shorthand to set Self::task to Task::Stop.
Sourcepub fn set_chat_controller(
&mut self,
cx: &Cx,
controller: Option<Arc<Mutex<ChatController>>>,
)
pub fn set_chat_controller( &mut self, cx: &Cx, controller: Option<Arc<Mutex<ChatController>>>, )
Set the chat controller for the model selector
Sourcepub fn set_bot_capabilities(
&mut self,
cx: &mut Cx,
capabilities: Option<BotCapabilities>,
)
pub fn set_bot_capabilities( &mut self, cx: &mut Cx, capabilities: Option<BotCapabilities>, )
Set the capabilities of the currently selected bot
Sourcepub fn set_stt_visible(&mut self, cx: &mut Cx, visible: bool)
pub fn set_stt_visible(&mut self, cx: &mut Cx, visible: bool)
Set whether the speech-to-text button is visible.
Methods from Deref<Target = View>
pub fn set_debug_dump(&mut self, cx: &mut Cx, debug: bool)
pub fn repaint(&mut self, cx: &mut Cx)
pub fn swap_child(&mut self, pos_a: usize, pos_b: usize)
pub fn child_index(&mut self, comp: &WidgetRef) -> Option<usize>
pub fn child_at_index(&mut self, index: usize) -> Option<&WidgetRef>
pub fn set_scroll_pos(&mut self, cx: &mut Cx, v: Vec2d)
pub fn area(&self) -> Area
pub fn walk_from_previous_size(&self, walk: Walk) -> Walk
pub fn child_count(&self) -> usize
pub fn debug_print_children(&self)
pub fn debug_props(&self) -> String
pub fn debug_dump_tree(&self, depth: usize) -> String
pub fn set_key_focus(&self, cx: &mut Cx)