pub trait HitExt {
// Required methods
fn primary_pointer_action_pos(&self) -> Option<DVec2>;
fn secondary_pointer_action_pos(&self) -> Option<DVec2>;
fn is_primary_pointer_action(&self) -> bool;
fn is_secondary_pointer_action(&self) -> bool;
}Required Methods
Sourcefn primary_pointer_action_pos(&self) -> Option<DVec2>
fn primary_pointer_action_pos(&self) -> Option<DVec2>
If the primary pointer action happened, returns the position where it happened.
Sourcefn secondary_pointer_action_pos(&self) -> Option<DVec2>
fn secondary_pointer_action_pos(&self) -> Option<DVec2>
If the secondary pointer action happened, returns the position where it happened.
Sourcefn is_primary_pointer_action(&self) -> bool
fn is_primary_pointer_action(&self) -> bool
This was a left mouse click or a simple touch screen tap.
Sourcefn is_secondary_pointer_action(&self) -> bool
fn is_secondary_pointer_action(&self) -> bool
This was a right mouse click or a long press on touch screen.