pub struct SttInput {
pub deref: View,
/* private fields */
}Fields
deref: ViewImplementations
Sourceimpl SttInput
impl SttInput
Sourcepub fn set_stt_utility(&mut self, utility: Option<SttUtility>)
pub fn set_stt_utility(&mut self, utility: Option<SttUtility>)
Sets the STT utility to be used for transcription.
Sourcepub fn stt_utility(&self) -> Option<&SttUtility>
pub fn stt_utility(&self) -> Option<&SttUtility>
Getter for the current STT utility.
Sourcepub fn start_recording(&mut self, cx: &mut Cx)
pub fn start_recording(&mut self, cx: &mut Cx)
Begins recording audio from the microphone.
Sourcepub fn finish_recording(&mut self, cx: &mut Cx, scope: &mut Scope<'_, '_>)
pub fn finish_recording(&mut self, cx: &mut Cx, scope: &mut Scope<'_, '_>)
Completes the recording and starts the transcription process.
Sourcepub fn cancel_recording(&mut self, cx: &mut Cx, _scope: &mut Scope<'_, '_>)
pub fn cancel_recording(&mut self, cx: &mut Cx, _scope: &mut Scope<'_, '_>)
Cancels the ongoing recording or transcription.
This stops the audio device and aborts the async transcription request.
Sourcepub fn transcribed(&self, actions: &Actions) -> Option<String>
pub fn transcribed(&self, actions: &Actions) -> Option<String>
When the transcription is ready, read it from the actions.
Methods from Deref<Target = View>
pub fn set_debug_dump(&mut self, cx: &mut Cx, debug: bool)
pub fn repaint(&mut self, cx: &mut Cx)
pub fn swap_child(&mut self, pos_a: usize, pos_b: usize)
pub fn child_index(&mut self, comp: &WidgetRef) -> Option<usize>
pub fn child_at_index(&mut self, index: usize) -> Option<&WidgetRef>
pub fn set_scroll_pos(&mut self, cx: &mut Cx, v: Vec2d)
pub fn area(&self) -> Area
pub fn walk_from_previous_size(&self, walk: Walk) -> Walk
pub fn child_count(&self) -> usize
pub fn debug_print_children(&self)
pub fn debug_props(&self) -> String
pub fn debug_dump_tree(&self, depth: usize) -> String
pub fn set_key_focus(&self, cx: &mut Cx)